def hello_python_demo():
    print("hello python!")